@@ -3027,7 +3027,7 @@ yylex()
 					/* NOTREACHED */
 				}
 				state = p->state;
-				yylval.s = p->name;
+				yylval.s = (char*) p->name;
 				return (p->token);
 			}
 			break;
@@ -3053,7 +3053,7 @@ yylex()
 					/* NOTREACHED */
 				}
 				state = p->state;
-				yylval.s = p->name;
+				yylval.s = (char*)p->name;
 				return (p->token);
 			}
 			state = CMD;
@@ -3070,7 +3070,10 @@ yylex()
 		dostr1:
 			if (cbuf[cpos] == ' ') {
 				cpos++;
-				state = state == OSTR ? STR2 : ++state;
+                                if (state == OSTR)
+                                  state = STR2;
+                                else
+                                  ++state;
 				return (SP);
 			}
 			break;
