@@ -1,3 +1,22 @@
+/*
+  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+  2009 Free Software Foundation, Inc.
+
+  This file is part of GNU Inetutils.
+
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
+
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
+
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -195,11 +214,9 @@ pam_user (const char *username, struct credentials *pcred)
       pamh = 0;
     }
 
-  if (pcred->name)
-    free (pcred->name);
+  free (pcred->name);
   pcred->name = strdup (username);
-  if (pcred->message)
-    free (pcred->message);
+  free (pcred->message);
   pcred->message = NULL;
 
   error = pam_start ("ftp", pcred->name, &PAM_conversation, &pamh);
