@@ -1,24 +1,23 @@
 /* changeif.c -- change the configuration of a network interface
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+  Free Software Foundation, Inc.
 
-   Copyright (C) 2001, 2002, 2007 Free Software Foundation, Inc.
+  This file is part of GNU Inetutils.
 
-   Written by Marcus Brinkmann.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 3
-   of the License, or (at your option) any later version.
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA.
- */
+/* Written by Marcus Brinkmann.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -49,15 +48,13 @@
   err = inet_aton (addr, &sin->sin_addr);				\
   if (!err)								\
     {									\
-      fprintf (stderr, "%s: `%s' is not a valid address\n",		\
-	       program_name, addr);					\
+      error (0, 0, "`%s' is not a valid address", addr);		\
       return -1;							\
     }									\
   err = ioctl (sfd, SIOCSIF##type, ifr);				\
   if (err < 0)								\
     {									\
-      fprintf (stderr, "%s: %s failed: %s\n", program_name,		\
-               "SIOCSIF" #type, strerror (errno));			\
+      error (0, errno, "%s failed", "SIOCSIF" #type); 		        \
       return -1;							\
     }
 
@@ -70,9 +67,8 @@ int
 set_address (int sfd, struct ifreq *ifr, char *address)
 {
 #ifndef SIOCSIFADDR
-  fprintf (stderr,
-	   "%s: Don't know how to set an interface address on this system.\n",
-	   program_name);
+  error (0, 0,
+	   "don't know how to set an interface address on this system");
   return -1;
 #else
   char *addr;
@@ -80,14 +76,12 @@ set_address (int sfd, struct ifreq *ifr, char *address)
 
   if (!host)
     {
-      fprintf (stderr, "%s: can not resolve `%s': ", program_name, address);
-      herror (NULL);
+      error (0, 0, "can not resolve `%s': %s", address, hstrerror (h_errno));
       return -1;
     }
   if (host->h_addrtype != AF_INET)
     {
-      fprintf (stderr, "%s: `%s' refers to an unknown address type",
-	       program_name, address);
+      error (0, 0, "`%s' refers to an unknown address type", address);
       return -1;
     }
 
@@ -106,8 +100,7 @@ int
 set_netmask (int sfd, struct ifreq *ifr, char *netmask)
 {
 #ifndef SIOCSIFNETMASK
-  printf ("%s: Don't know how to set an interface netmask on this system.\n",
-	  program_name);
+  error (0, 0, "don't know how to set an interface netmask on this system");
   return -1;
 #else
 
@@ -122,9 +115,8 @@ int
 set_dstaddr (int sfd, struct ifreq *ifr, char *dstaddr)
 {
 #ifndef SIOCSIFDSTADDR
-  printf
-    ("%s: Don't know how to set an interface peer address on this system.\n",
-     program_name);
+  error (0, 0,
+         "don't know how to set an interface peer address on this system");
   return -1;
 #else
   SIOCSIF (DSTADDR, dstaddr) if (verbose)
@@ -138,9 +130,8 @@ int
 set_brdaddr (int sfd, struct ifreq *ifr, char *brdaddr)
 {
 #ifndef SIOCSIFBRDADDR
-  printf
-    ("%s: Don't know how to set an interface broadcast address on this system.\n",
-     program_name);
+  error (0, 0,
+         "don't know how to set an interface broadcast address on this system");
   return -1;
 #else
   SIOCSIF (BRDADDR, brdaddr) if (verbose)
@@ -154,8 +145,8 @@ int
 set_mtu (int sfd, struct ifreq *ifr, int mtu)
 {
 #ifndef SIOCSIFMTU
-  printf ("%s: Don't know how to set the interface mtu on this system.\n",
-	  program_name);
+  error (0, 0, 
+         "don't know how to set the interface mtu on this system");
   return -1;
 #else
   int err = 0;
@@ -164,8 +155,7 @@ set_mtu (int sfd, struct ifreq *ifr, int mtu)
   err = ioctl (sfd, SIOCSIFMTU, ifr);
   if (err < 0)
     {
-      fprintf (stderr, "%s: SIOCSIFMTU failed: %s\n",
-	       program_name, strerror (errno));
+      error (0, errno, "SIOCSIFMTU failed");
       return -1;
     }
   if (verbose)
@@ -178,8 +168,8 @@ int
 set_metric (int sfd, struct ifreq *ifr, int metric)
 {
 #ifndef SIOCSIFMETRIC
-  printf ("%s: Don't know how to set the interface metric on this system.\n",
-	  program_name);
+  error (0, 0,
+         "don't know how to set the interface metric on this system");
   return -1;
 #else
   int err = 0;
@@ -188,8 +178,7 @@ set_metric (int sfd, struct ifreq *ifr, int metric)
   err = ioctl (sfd, SIOCSIFMETRIC, ifr);
   if (err < 0)
     {
-      fprintf (stderr, "%s: SIOCSIFMETRIC failed: %s\n",
-	       program_name, strerror (errno));
+      error (0, errno, "SIOCSIFMETRIC failed");
       return -1;
     }
   if (verbose)
