@@ -1,23 +1,23 @@
 /* printif.c -- print an interface configuration
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+  Free Software Foundation, Inc.
 
-   Copyright (C) 2001, 2002, 2007 Free Software Foundation, Inc.
+  This file is part of GNU Inetutils.
 
-   Written by Marcus Brinkmann.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 3
-   of the License, or (at your option) any later version.
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA. */
+/* Written by Marcus Brinkmann.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -94,6 +94,19 @@ struct format_handle format_handles[] = {
   {"mtu", fh_mtu},
   {"metric?", fh_metric_query},
   {"metric", fh_metric},
+#ifdef HAVE_STRUCT_IFREQ_IFR_MAP
+  {"map?", fh_map_query},
+  {"irq?", fh_irq_query},
+  {"irq", fh_irq},
+  {"baseaddr?", fh_baseaddr_query},
+  {"baseaddr", fh_baseaddr},
+  {"memstart?", fh_memstart_query},
+  {"memstart", fh_memstart},
+  {"memend?", fh_memend_query},
+  {"memend", fh_memend},
+  {"dma?", fh_dma_query},
+  {"dma", fh_dma},
+#endif
   {NULL, NULL}
 };
 
@@ -180,6 +193,62 @@ put_int (format_data_t form, int argc, char *argv[], int nr)
   had_output = 1;
 }
 
+void
+put_ulong (format_data_t form, int argc, char *argv[], unsigned long value)
+{
+  char *fmt;
+  if (argc > 0)
+    {
+      char *p = argv[0];
+
+      if (*p != '%')
+	fmt = "%lu";
+      else
+	{
+	  p++;
+
+	  while (isdigit (*p))
+	    p++;
+
+	  if (*p == '#')
+	    p++;
+
+	  if (*p == 'l')
+	    p++;
+	  
+	  switch (*p)
+	    {
+	    default:
+	    case 'i':
+	    case 'd':
+	    case 'D':
+	      *p = 'i';
+	      break;
+	    case 'x':
+	    case 'h':
+	      *p = 'x';
+	      break;
+	    case 'X':
+	    case 'H':
+	      *p = 'X';
+	      break;
+	    case 'o':
+	    case 'O':
+	      *p = 'o';
+	      break;
+	    }
+	  p++;
+	  *p = '\0';
+	  fmt = argv[0];
+	}
+    }
+  else
+    fmt = "%lu";
+
+  *column += printf (fmt, value);
+  had_output = 1;
+}
+
 void
 select_arg (format_data_t form, int argc, char *argv[], int nr)
 {
@@ -449,11 +518,9 @@ fh_index (format_data_t form, int argc, char *argv[])
   int indx = if_nametoindex (form->name);
 
   if (indx == 0)
-    {
-      fprintf (stderr, "%s: No index number found for interface `%s': %s\n",
-	       program_name, form->name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "No index number found for interface `%s'",
+	   form->name);
   *column += printf ("%i", indx);
   had_output = 1;
 }
@@ -474,11 +541,9 @@ fh_addr (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFADDR
   if (ioctl (form->sfd, SIOCGIFADDR, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFADDR failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFADDR failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     put_addr (form, argc, argv, &form->ifr->ifr_addr);
 #else
@@ -503,11 +568,9 @@ fh_netmask (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFNETMASK
   if (ioctl (form->sfd, SIOCGIFNETMASK, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFNETMASK failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFNETMASK failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     put_addr (form, argc, argv, &form->ifr->ifr_netmask);
 #else
@@ -543,11 +606,9 @@ fh_brdaddr (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFBRDADDR
   if (ioctl (form->sfd, SIOCGIFBRDADDR, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFBRDADDR failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFBRDADDR failed for interface `%s'",
+           form->ifr->ifr_name);
   else
     put_addr (form, argc, argv, &form->ifr->ifr_broadaddr);
 #else
@@ -583,11 +644,9 @@ fh_dstaddr (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFDSTADDR
   if (ioctl (form->sfd, SIOCGIFDSTADDR, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFDSTADDR failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFDSTADDR failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     put_addr (form, argc, argv, &form->ifr->ifr_dstaddr);
 #else
@@ -612,11 +671,9 @@ fh_mtu (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFMTU
   if (ioctl (form->sfd, SIOCGIFMTU, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFMTU failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFMTU failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     put_int (form, argc, argv, form->ifr->ifr_mtu);
 #else
@@ -641,11 +698,9 @@ fh_metric (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFMETRIC
   if (ioctl (form->sfd, SIOCGIFMETRIC, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFMETRIC failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFMETRIC failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     put_int (form, argc, argv, form->ifr->ifr_metric);
 #else
@@ -670,11 +725,9 @@ fh_flags (format_data_t form, int argc, char *argv[])
 {
 #ifdef SIOCGIFFLAGS
   if (ioctl (form->sfd, SIOCGIFFLAGS, form->ifr) < 0)
-    {
-      fprintf (stderr, "%s: SIOCGIFFLAGS failed for interface `%s': %s\n",
-	       program_name, form->ifr->ifr_name, strerror (errno));
-      exit (EXIT_FAILURE);
-    }
+    error (EXIT_FAILURE, errno,
+           "SIOCGIFFLAGS failed for interface `%s'",
+	   form->ifr->ifr_name);
   else
     {
       if (argc >= 1)
@@ -693,6 +746,107 @@ fh_flags (format_data_t form, int argc, char *argv[])
 #endif
 }
 
+#ifdef HAVE_STRUCT_IFREQ_IFR_MAP
+
+void
+fh_map_query (format_data_t form, int argc, char *argv[])
+{
+#ifdef SIOCGIFMAP
+  if (ioctl (form->sfd, SIOCGIFMAP, form->ifr) >= 0)
+    select_arg (form, argc, argv, 0);
+  else
+#endif
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_irq_query (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.irq)
+    select_arg (form, argc, argv, 0);
+  else
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_irq (format_data_t form, int argc, char *argv[])
+{
+  put_int (form, argc, argv, form->ifr->ifr_map.irq);
+}
+
+void
+fh_baseaddr_query (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.base_addr >= 0x100)
+    select_arg (form, argc, argv, 0);
+  else
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_baseaddr (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.base_addr >= 0x100)  
+    put_int (form, argc, argv, form->ifr->ifr_map.base_addr);
+  else
+    put_string (form, "(not available)");
+}
+
+void
+fh_memstart_query (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.mem_start)
+    select_arg (form, argc, argv, 0);
+  else
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_memstart (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.mem_start)  
+    put_ulong (form, argc, argv, form->ifr->ifr_map.mem_start);
+  else
+    put_string (form, "(not available)");
+}
+
+void
+fh_memend_query (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.mem_end)
+    select_arg (form, argc, argv, 0);
+  else
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_memend (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.mem_end)  
+    put_ulong (form, argc, argv, form->ifr->ifr_map.mem_end);
+  else
+    put_string (form, "(not available)");
+}
+
+void
+fh_dma_query (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.dma)
+    select_arg (form, argc, argv, 0);
+  else
+    select_arg (form, argc, argv, 1);
+}
+
+void
+fh_dma (format_data_t form, int argc, char *argv[])
+{
+  if (form->ifr->ifr_map.dma)  
+    put_int (form, argc, argv, form->ifr->ifr_map.dma);
+  else
+    put_string (form, "(not available)");
+}
+#endif
+
 void
 print_interfaceX (format_data_t form, int quiet)
 {
