@@ -1,24 +1,23 @@
-/* system/osf.c -- OSF specific code for ifconfig
+/* osf.c -- OSF specific code for ifconfig
+  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009
+  Free Software Foundation, Inc.
 
-   Copyright (C) 2001, 2002, 2007 Free Software Foundation, Inc.
+  This file is part of GNU Inetutils.
 
-   Written by Marcus Brinkmann.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 3
-   of the License, or (at your option) any later version.
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA.
- */
+/* Written by Marcus Brinkmann.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -59,12 +58,10 @@
 
 const char *system_default_format "osf"/* Argument parsing stuff.  */
 const char *system_help = "\
-  NAME [AF]
-or
-  NAME AF [ADDR [DSTADDR]] [broadcast BRDADDR]\n\
-  [netmask MASK] [metric N]";
+NAME [AF]\n\
+NAME AF [ADDR [DSTADDR]] [broadcast BRDADDR] [netmask MASK] [metric N]";
 
-const char *system_help_options;
+struct argp_child system_argp_child;
 
 int
 system_parse_opt (struct ifconfig **ifp, char option, char *optarg)
@@ -140,18 +137,15 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
   switch (expect)
     {
     case EXPECT_BROADCAST:
-      fprintf (stderr, "%s: option `broadcast' requires an argument\n",
-	       program_name);
+      error (0, 0, "option `broadcast' requires an argument");
       break;
 
     case EXPECT_NETMASK:
-      fprintf (stderr, "%s: option `netmask' requires an argument\n",
-	       program_name);
+      error (0, 0, "option `netmask' requires an argument");
       break;
 
     case EXPECT_METRIC:
-      fprintf (stderr, "%s: option `metric' requires an argument\n",
-	       program_name);
+      error (0, 0, "option `metric' requires an argument");
       break;
 
     case EXPECT_NAME:
@@ -160,10 +154,7 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
       expect = EXPECT_NOTHING;
       break;
     }
-  if (expect != EXPECT_NOTHING)
-    usage (EXIT_FAILURE);
-
-  return 1;
+  return expect == EXPECT_NOTHING;
 }
 
 int
