@@ -581,7 +581,11 @@ setup (struct servtab *sep)
 #ifdef IPV6
   if (sep->se_family == AF_INET6)
     {
-      int val = sep->se_v4mapped;
+      /* Reverse the value of SEP->se_v4mapped, since otherwise if
+	 using `tcp' as a protocol type all connections will be mapped
+	 to IPv6, and with `tcp6' they get mapped IPv4 mapped to
+	 IPv6.  */
+      int val = sep->se_v4mapped ? 0 : 1;
       if (setsockopt (sep->se_fd, IPPROTO_IPV6, IPV6_V6ONLY,
 		      (char *) &val, sizeof (val)) < 0)
 	syslog (LOG_ERR, "setsockopt (IPV6_V6ONLY): %m");
@@ -822,8 +826,6 @@ int
 expand_enter (struct servtab *sep)
 {
   int err;
-  const int on = 1;
-  const int off = 0;
   struct addrinfo *result, *rp;
   struct protoent *proto;
   struct servtab *cp;
@@ -1013,7 +1015,8 @@ getconfigent (FILE *fconfig, const char *file, size_t *line)
 {
   static struct servtab serv;
   struct servtab *sep = &serv;
-  size_t argc = 0, i;
+  int argc = 0;
+  size_t i;
   char **argv = NULL;
   char *node, *service;
   static char TCPMUX_TOKEN[] = "tcpmux/";
