@@ -3,10 +3,10 @@
    Copyright (C) 1992-2001, 2003, 2004, 2005, 2006 Free Software
    Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,8 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Written by jla; revised by djm */
 
@@ -32,6 +31,7 @@
 #include <stdbool.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 
 #include "xalloc.h"
 
@@ -39,10 +39,6 @@
 # include "unlocked-io.h"
 #endif
 
-#ifndef SIZE_MAX
-# define SIZE_MAX ((size_t) -1)
-#endif
-
 /* Copy UT->ut_name into storage obtained from malloc.  Then remove any
    trailing spaces from the copy, NUL terminate it, and return the copy.  */
 
@@ -69,13 +65,13 @@ extract_trimmed_name (const STRUCT_UTMP *ut)
 static inline bool
 desirable_utmp_entry (STRUCT_UTMP const *u, int options)
 {
-  int up = IS_USER_PROCESS (u);
-  if ((options & READ_UTMP_USER_PROCESS) && !up)
+  bool user_proc = IS_USER_PROCESS (u);
+  if ((options & READ_UTMP_USER_PROCESS) && !user_proc)
     return false;
   if ((options & READ_UTMP_CHECK_PIDS)
-      && up
+      && user_proc
       && (UT_PID (u) <= 0
-	  || (kill (UT_PID (u), 0) < 0 && errno == ESRCH)))
+          || (kill (UT_PID (u), 0) < 0 && errno == ESRCH)))
     return false;
   return true;
 }
@@ -91,7 +87,7 @@ desirable_utmp_entry (STRUCT_UTMP const *u, int options)
 
 int
 read_utmp (char const *file, size_t *n_entries, STRUCT_UTMP **utmp_buf,
-	   int options)
+           int options)
 {
   size_t n_read = 0;
   size_t n_alloc = 0;
@@ -109,10 +105,10 @@ read_utmp (char const *file, size_t *n_entries, STRUCT_UTMP **utmp_buf,
   while ((u = GET_UTMP_ENT ()) != NULL)
     if (desirable_utmp_entry (u, options))
       {
-	if (n_read == n_alloc)
-	  utmp = x2nrealloc (utmp, &n_alloc, sizeof *utmp);
+        if (n_read == n_alloc)
+          utmp = x2nrealloc (utmp, &n_alloc, sizeof *utmp);
 
-	utmp[n_read++] = *u;
+        utmp[n_read++] = *u;
       }
 
   END_UTMP_ENT ();
@@ -127,7 +123,7 @@ read_utmp (char const *file, size_t *n_entries, STRUCT_UTMP **utmp_buf,
 
 int
 read_utmp (char const *file, size_t *n_entries, STRUCT_UTMP **utmp_buf,
-	   int options)
+           int options)
 {
   size_t n_read = 0;
   size_t n_alloc = 0;
@@ -141,9 +137,9 @@ read_utmp (char const *file, size_t *n_entries, STRUCT_UTMP **utmp_buf,
   for (;;)
     {
       if (n_read == n_alloc)
-	utmp = x2nrealloc (utmp, &n_alloc, sizeof *utmp);
+        utmp = x2nrealloc (utmp, &n_alloc, sizeof *utmp);
       if (fread (&utmp[n_read], sizeof utmp[n_read], 1, f) == 0)
-	break;
+        break;
       n_read += desirable_utmp_entry (&utmp[n_read], options);
     }
 
