@@ -1,29 +1,33 @@
 /* shishi.c -- functions to use kerberos V with shishi
-   Copyright (C) 1990-1999, 2000, 2002, 2007 Free Software Foundation, Inc.
+  Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
+  Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+  This file is part of GNU Inetutils.
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
 #if HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #ifdef SHISHI
+# include <string.h>
 # include <stdlib.h>
 # include <errno.h>
 # include <shishi.h>
 # include <syslog.h>
+# include <unistd.h>
 # include <shishi_def.h>
 
 /* shishi authentication */
