@@ -1,4 +1,24 @@
-/*-
+/*
+  Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
+  Foundation, Inc.
+
+  This file is part of GNU Inetutils.
+
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
+
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
+
+/*
  * Copyright (c) 1991, 1993
  *	The Regents of the University of California.  All rights reserved.
  *
@@ -10,7 +30,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -68,6 +88,9 @@
 #  include <string.h>
 # endif
 
+#include <stdio.h>
+#include "genget.h"
+
 /*
  * These functions pointers point to the current routines
  * for encrypting and decrypting data.
@@ -770,20 +793,7 @@ encrypt_request_start (data, cnt)
 static unsigned char str_keyid[(MAXKEYLEN * 2) + 5] =
   { IAC, SB, TELOPT_ENCRYPT };
 
-encrypt_enc_keyid (keyid, len)
-     unsigned char *keyid;
-     int len;
-{
-  encrypt_keyid (&ki[1], keyid, len);
-}
-
-encrypt_dec_keyid (keyid, len)
-     unsigned char *keyid;
-     int len;
-{
-  encrypt_keyid (&ki[0], keyid, len);
-}
-
+static void
 encrypt_keyid (kp, keyid, len)
      struct key_info *kp;
      unsigned char *keyid;
@@ -834,6 +844,22 @@ encrypt_keyid (kp, keyid, len)
   encrypt_send_keyid (dir, kp->keyid, kp->keylen, 0);
 }
 
+void
+encrypt_enc_keyid (keyid, len)
+     unsigned char *keyid;
+     int len;
+{
+  encrypt_keyid (&ki[1], keyid, len);
+}
+
+void
+encrypt_dec_keyid (keyid, len)
+     unsigned char *keyid;
+     int len;
+{
+  encrypt_keyid (&ki[0], keyid, len);
+}
+
 void
 encrypt_send_keyid (dir, keyid, keylen, saveit)
      int dir;
