@@ -1,22 +1,21 @@
-/* Copyright (C) 1998, 2001, 2002, 2004, 2005, 2007, 2008
-   Free Software Foundation, Inc.
+/*
+  Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
+  Inc.
 
-   This file is part of GNU Inetutils.
+  This file is part of GNU Inetutils.
 
-   GNU Inetutils is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+  GNU Inetutils is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or (at
+  your option) any later version.
 
-   GNU Inetutils is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+  GNU Inetutils is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with GNU Inetutils; see the file COPYING.  If not, write
-   to the Free Software Foundation, Inc., 51 Franklin Street,
-   Fifth Floor, Boston, MA 02110-1301 USA. */
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -65,7 +64,7 @@ init_data_buffer (u_char * pat, int len)
   if (data_length == 0)
     return;
 
-  data_buffer = (u_char *) xmalloc (data_length);
+  data_buffer = xmalloc (data_length);
 
   if (pat)
     {
@@ -145,17 +144,19 @@ nsqrt (double a, double prec)
 int
 _ping_setbuf (PING * p, bool use_ipv6)
 {
-  if (!p->ping_buffer) {
-    p->ping_buffer = malloc (_PING_BUFLEN (p, use_ipv6));
-    if (!p->ping_buffer)
-      return -1;
-  }
-  if (!p->ping_cktab) {
-    p->ping_cktab = malloc (p->ping_cktab_size);
-    if (!p->ping_cktab)
-      return -1;
-    memset (p->ping_cktab, 0, p->ping_cktab_size);
-  }
+  if (!p->ping_buffer)
+    {
+      p->ping_buffer = malloc (_PING_BUFLEN (p, use_ipv6));
+      if (!p->ping_buffer)
+	return -1;
+    }
+  if (!p->ping_cktab)
+    {
+      p->ping_cktab = malloc (p->ping_cktab_size);
+      if (!p->ping_cktab)
+	return -1;
+      memset (p->ping_cktab, 0, p->ping_cktab_size);
+    }
   return 0;
 }
 
@@ -214,3 +215,16 @@ ping_unset_data (PING * p)
   _ping_freebuf (p);
 }
 
+int
+ping_timeout_p (struct timeval *start_time, int timeout)
+{
+  struct timeval now;
+  gettimeofday (&now, NULL);
+  if (timeout != -1)
+    {
+      tvsub (&now, start_time);
+      if (now.tv_sec >= timeout)
+        return 1;
+    }
+  return 0;
+}
