@@ -124,10 +124,6 @@ int doencrypt = 0;
 # endif
 #endif /* KERBEROS  */
 
-#if !defined (S_ISTXT) && defined (S_ISVTX)
-# define S_ISTXT S_ISVTX
-#endif
-
 const char doc[] = "Remote copy SOURCE to DEST, or multiple SOURCE(s) to DIRECTORY.";
 const char arg_doc[] = "SOURCE DEST\n"
                        "SOURCE... DIRECTORY\n"
@@ -357,7 +353,7 @@ main (int argc, char *argv[])
 void
 toremote (char *targ, int argc, char *argv[])
 {
-  int i, len, tos;
+  int i, tos;
   char *bp, *host, *src, *suser, *thost, *tuser;
 
   *targ++ = 0;
@@ -589,7 +585,7 @@ source (int argc, char *argv[])
 	  if (response () < 0)
 	    goto next;
 	}
-#define RCP_MODEMASK	(S_ISUID|S_ISGID|S_ISTXT|S_IRWXU|S_IRWXG|S_IRWXO)
+#define RCP_MODEMASK	(S_ISUID|S_ISGID|S_ISVTX|S_IRWXU|S_IRWXG|S_IRWXO)
       snprintf (buf, sizeof buf,
 		(sizeof (stb.st_size) > sizeof (long)
 		 ? "C%04o %qd %s\n"
@@ -686,7 +682,7 @@ rsource (char *name, struct stat *statp)
       return;
     }
 
-  while (dp = readdir (dirp))
+  while ((dp = readdir (dirp)))
     {
       if (!strcmp (dp->d_name, ".") || !strcmp (dp->d_name, ".."))
 	continue;
