@@ -190,6 +190,9 @@ int local_dot_count;
 
 struct winsize win = { 0, 0, 0, 0 };
 
+extern int iruserok (uint32_t raddr, int superuser,
+                     const char *ruser, const char *luser);
+
 void rlogin_daemon (int maxchildren, int port);
 int rlogind_auth (int fd, struct auth_data *ap);
 void setup_tty (int fd, struct auth_data *ap);
@@ -423,7 +426,7 @@ void
 rlogin_daemon (int maxchildren, int port)
 {
   pid_t pid;
-  size_t size;
+  socklen_t size;
   struct sockaddr_in saddr;
   int listenfd, fd;
 
@@ -592,7 +595,8 @@ rlogind_auth (int fd, struct auth_data *ap)
       {
 	u_char optbuf[BUFSIZ / 3], *cp;
 	char lbuf[BUFSIZ], *lp;
-	int optsize = sizeof (optbuf), ipproto;
+	socklen_t optsize = sizeof (optbuf);
+	int ipproto;
 	struct protoent *ip;
 
 	if ((ip = getprotobyname ("ip")) != NULL)
@@ -710,7 +714,7 @@ exec_login (int authenticated, struct auth_data *ap)
 int
 rlogind_mainloop (int infd, int outfd)
 {
-  size_t size;
+  socklen_t size;
   struct auth_data auth_data;
   int true;
   char c;
