@@ -17,10 +17,6 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
