@@ -18,6 +18,8 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
+#include <config.h>
+
 #include "telnetd.h"
 
 #ifdef HAVE_SYS_UTSNAME_H
@@ -220,10 +222,11 @@ static struct
   int modnum;
 } debug_mode[debug_max_mode] =
 {
-"options", debug_options,
-    "report", debug_report,
-    "netdata", debug_net_data,
-    "ptydata", debug_pty_data, "auth", debug_auth,};
+  {"options", debug_options},
+  {"report", debug_report},
+  {"netdata", debug_net_data},
+  {"ptydata", debug_pty_data},
+  {"auth", debug_auth},};
 
 void
 parse_debug_level (char *str)
@@ -660,6 +663,8 @@ telnetd_run ()
 	ptyflush ();
     }
   cleanup (0);
+
+  return 0;
 }
 
 void
